@@ -7,25 +7,21 @@ use 5.10.1;
 
 use vars qw($VERSION @EXPORT_OK);
 use Exporter;
-use Encode qw/encode/;
 use base qw(Exporter);
 
 use autodie qw(open close);
 use Carp;
 
-use Alien::NSS;
-
 use Crypt::NSS::X509::Certificate;
 use Crypt::NSS::X509::CertList;
 use Crypt::NSS::X509::CRL;
 
-our $VERSION = '0.03';
+our $VERSION = '0.03_01';
 
 @EXPORT_OK = qw(
 );
 
 
-
 BOOT_XS: {
   require DynaLoader;
 
